### Issue Type

- [x] Bug
- [ ] Enhancement
- [ ] Docs
- [ ] Miscellaneous

### Description

For bugs, explain what is happening and how it differs from the expected behavior. For enhancements, explain the desired functionality.

### Example

For bugs, if at all possible, provide a short snipped which reproduces the issue,
or link to a file in another repository where the issue is demonstrated.

For enhancements this is not as critical, but if possible provide an example
of the proposed usage of the enhancement.  If a reference implementation has
been implemented and you desire to have it merged into Dymos, site that reference
implementation here before issuing a pull request. The pull request should then  
cite this issue number in the "Related issues" section.

### Environment

Operating System: <i.e. OS X 10.14.6, Windows 10, Ubuntu 16.04>
Python environment: <i.e. Anaconda Python 3.7.1>
Packages: <versions of Dymos, OpenMDAO, and other pertinent Python packages. You can just paste the output of `pip freeze` here.>
